summaryrefslogtreecommitdiff
path: root/src/ai
diff options
context:
space:
mode:
authorMichael Lutz <michi@icosahedron.de>2021-10-31 22:07:22 +0100
committerMichael Lutz <michi@icosahedron.de>2021-12-16 22:28:32 +0100
commiteab18f06a47e558fe313cb86c855e8949b01feed (patch)
treea6dd29dc2ea3eb44ea2432151fa392ccd31c7d73 /src/ai
parent0f64ee5ce1548d9cda69917f27c5b1a3cb91823d (diff)
downloadopenttd-eab18f06a47e558fe313cb86c855e8949b01feed.tar.xz
Codechange: Pass additional data as byte stream to command callbacks.
Diffstat (limited to 'src/ai')
-rw-r--r--src/ai/ai_instance.cpp10
1 files changed, 4 insertions, 6 deletions
diff --git a/src/ai/ai_instance.cpp b/src/ai/ai_instance.cpp
index 509ed70d2..576a81637 100644
--- a/src/ai/ai_instance.cpp
+++ b/src/ai/ai_instance.cpp
@@ -92,14 +92,12 @@ ScriptInfo *AIInstance::FindLibrary(const char *library, int version)
/**
* DoCommand callback function for all commands executed by AIs.
- * @param result The result of the command.
* @param cmd cmd as given to DoCommandPInternal.
+ * @param result The result of the command.
* @param tile The tile on which the command was executed.
* @param p1 p1 as given to DoCommandPInternal.
* @param p2 p2 as given to DoCommandPInternal.
* @param text text as given to DoCommandPInternal.
*/
-void CcAI(const CommandCost &result, Commands cmd, TileIndex tile, uint32 p1, uint32 p2, const std::string &text)
+void CcAI(Commands cmd, const CommandCost &result, TileIndex tile, const CommandDataBuffer &data)
{
/*
* The company might not exist anymore. Check for this.
@@ -110,7 +108,7 @@ void CcAI(const CommandCost &result, Commands cmd, TileIndex tile, uint32 p1, ui
const Company *c = Company::GetIfValid(_current_company);
if (c == nullptr || c->ai_instance == nullptr) return;
- if (c->ai_instance->DoCommandCallback(result, tile, p1, p2, cmd)) {
+ if (c->ai_instance->DoCommandCallback(result, tile, data, cmd)) {
c->ai_instance->Continue();
}
}
@@ -92,14 +92,12 @@ ScriptInfo *AIInstance::FindLibrary(const char *library, int version)
* @param tile The tile on which the command was executed.
- * @param p1 p1 as given to DoCommandPInternal.
- * @param p2 p2 as given to DoCommandPInternal.
- * @param text text as given to DoCommandPInternal.
+ * @param data Command data as given to Command<>::Post.
*/